#!/bin/sh

die()
{
	echo "$CE$N: fatal error: $*$CN" >&2
	exit 1
}

# enable colors only on terminal devices
TPUT="`which tput`"
if test -t 0 -a -t 1 -a -n "$TPUT"
then
    CI="`$TPUT setf 6 || true`"
    CE="`$TPUT setf 4 || true`"
    CX="`$TPUT setf 2 || true`"
    CN="`$TPUT sgr0 || true`"
else
    CI=''
    CE=''
    CX=''
    CN=''
fi

# default name of the repository
if [[ $1 ]]
then
	dir="$1"
else
	dir="repo"
fi

# can't do any mirroring without reprepro
rpp=`which reprepro`
if [ ! "$rpp" ]
then
	die "reprepro is not installed. (try: sudo aptitude install reprepro)"
fi

# get the user's Single ID
if ! email="`git config --global --get user.email`" ||
   ! echo $email | grep -q 'samsung.com$'
then
    die "Please setup up your email address first using:
    git config --global user.email yoursingleid@samsung.com"
fi
SINGLE_ID="`echo \"$email\" | cut -d@ -f1`"

# mirror URL base
base="ssh://$SINGLE_ID@165.213.180.233/home/slp2.0/debian/www"

# mirror the armel repository
mkdir -p "$dir/apt.sbs/armel/conf"
cat > "$dir/apt.sbs/armel/conf/distributions" <<EOF
Codename: slp2-target/snapshots/SLP_20120501_1
Origin: slp
Suite: unstable
Components: main contrib non-free
Architectures: armel
Update: slp2-target-update
EOF

cat > "$dir/apt.sbs/armel/conf/updates" <<EOF
Name: slp2-target-update
Method: $base/apt.sbs/armel
EOF

# mirror the i386 repository
mkdir -p "$dir/apt.sbs/i386/conf"
cat > "$dir/apt.sbs/i386/conf/distributions" <<EOF
Codename: slp2-target/snapshots/SLP_20120501_1
Origin: slp
Suite: unstable
Components: main contrib non-free
Architectures: i386
Update: slp2-target-update
EOF

cat > "$dir/apt.sbs/i386/conf/updates" <<EOF
Name: slp2-target-update
Method: $base/apt.sbs/i386
EOF

# mirror the tools repository
mkdir -p "$dir/apt.sbs/tools/conf"
cat > "$dir/apt.sbs/tools/conf/distributions" <<EOF
Codename: slp2-tools
Origin: slp
Suite: unstable
Components: main contrib non-free
Architectures: i386
Update: slp2-tools-update
EOF

cat > "$dir/apt.sbs/tools/conf/updates" <<EOF
Name: slp2-tools-update
Method: $base/apt.sbs/tools
EOF

# mirror the debian/squeeze repository
mkdir -p "$dir/mirror/conf"
cat > "$dir/mirror/conf/distributions" <<EOF
Codename: squeeze
Architectures: i386
Description: Debian Squeeze
Components: main contrib non-free
Update: debian-squeeze-update
EOF

cat > "$dir/mirror/conf/updates" <<EOF
Name: debian-squeeze-update
Architectures: i386
Method: $base/mirror
EOF
# FIXME: filter the list of packages to reduce repository size
#FilterList: purge mirror.packages

# do the mirroring
echo "$CI""Mirroring armel""$CN"
(cd "$dir/apt.sbs/armel" && "$rpp" update)
echo "$CI""Mirroring tools""$CN"
(cd "$dir/apt.sbs/tools" && "$rpp" update)
echo "$CI""Mirroring i386""$CN"
(cd "$dir/apt.sbs/i386" && "$rpp" update)
echo "$CI""Mirroring Debian""$CN"
(cd "$dir/mirror" && "$rpp" update)
